@@ -287,10 +287,6 @@
         <source>Unable to open report file!</source>
         <translation>¡No es posible abrir el archivo de reporte!</translation>
     </message>
-    <message>
-        <source>invalid SQL or failed DB connection:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Music Summary</source>
         <translation type="unfinished"></translation>
@@ -379,6 +375,26 @@
         <source>Sound Panel Fifth and Later Play Output</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>invalid SQL or failed DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">Todo</translation>
+    </message>
+    <message>
+        <source>Relative</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NaturalLog Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -767,6 +783,52 @@ Color</translation>
         <source>Importing</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEdit</name>
+    <message>
+        <source>&amp;Audition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Pause</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Final</translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEditDialog</name>
+    <message>
+        <source>Set Cue Point</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Cancelar</translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -1825,6 +1887,13 @@ Do you still want to proceed?</source>
         <translation type="obsolete">RDLogManager</translation>
     </message>
 </context>
+<context>
+    <name>RDPanelButton</name>
+    <message>
+        <source>No Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPasswd</name>
     <message>
