@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.194.6.3 2012/07/24 20:27:01 cvs Exp $
+//      $Id: rd.h,v 1.194.6.13 2013/12/27 22:12:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -180,6 +180,16 @@
  */
 #define MAX_PANELS 50
 
+/*
+ * Maximum Cart Number
+ */
+#define RD_MAX_CART_NUMBER 999999
+
+/*
+ * Maximum Cut Number
+ */
+#define RD_MAX_CUT_NUMBER 999
+
 /*
  * In negative 1/100ths of a dB
  */
@@ -242,6 +252,12 @@
 #define RD_SERVICE_NAME "Production"
 #define RD_SERVICE_DESCRIPTION "Default Audio Service"
 
+/*
+ * RDSelect Label
+ * (Used for the RDSelect entry in RDAdmin->ManageHosts)
+ */
+#define RD_RDSELECT_LABEL "[RDSelect]"
+
 /*
  * Default Maximum POST Length (bytes)
  */
@@ -350,7 +366,7 @@
 #define CAE_MAX_ARGS 10
 #define CAE_MAX_LENGTH 256
 #define CAE_POLL_INTERVAL 50
-#define CAE_MAX_CONNECTIONS 32
+#define CAE_MAX_CONNECTIONS 128
 
 /*
  * Default Sample Rate
@@ -405,6 +421,15 @@
  */
 #define RDAIRPLAY_LOG_QUANTITY 3
 
+/*
+ * Cue Editor Colors
+ */
+#define RD_CUEEDITOR_KNOB_COLOR blue
+#define RD_CUEEDITOR_PLAY_MARKER black
+#define RD_CUEEDITOR_START_MARKER red
+#define RD_CUEEDITOR_BUTTON_FLASH_PERIOD 200
+#define RD_CUEEDITOR_AUDITION_PREROLL 5000
+
 /*
  * Log Colors
  */
@@ -454,6 +479,10 @@
 #define RD_LIVEWIRE_GPIO_BUNDLE_SIZE 5
 #define RD_LIVEWIRE_DEFAULT_LOAD RDLiveWireDestination::LoadHighZ
 #define RD_LIVEWIRE_MAX_SOURCE 0x7FFF
+#define RD_LIVEWIRE_GPIO_MCAST_ADDR "239.192.255.4"
+#define RD_LIVEWIRE_GPIO_SEND_PORT 2055
+#define RD_LIVEWIRE_GPIO_RECV_PORT 2060
+#define RD_LIVEWIRE_GPIO_PULSE_WIDTH 100
 
 /*
  * Number of Carts to Include in a 'Limited' Search
@@ -476,5 +505,66 @@
 #define RD_ANON_FTP_USERNAME "anonymous"
 #define RD_ANON_FTP_PASSWORD "rivendell"
 
+/*
+ * Status Monitor Height
+ */
+#define RDMONITOR_HEIGHT 30
+
+/*
+ * RDAirPlay Colors
+ */
+#define RDPANEL_SETUP_FLASH_COLOR Qt::blue
+#define RDPANEL_RESET_FLASH_COLOR Qt::blue
+#define RDPANEL_PLAY_BACKGROUND_COLOR Qt::red
+#define RDPANEL_PAUSED_BACKGROUND_COLOR Qt::cyan
+#define BUTTON_STOPPED_BACKGROUND_COLOR Qt::green
+#define BUTTON_PLAY_BACKGROUND_COLOR Qt::red
+#define BUTTON_PLAY_TEXT_COLOR Qt::black
+#define BUTTON_PAUSE_BACKGROUND_COLOR Qt::cyan
+#define BUTTON_PAUSE_TEXT_COLOR Qt::black
+#define BUTTON_FROM_BACKGROUND_COLOR Qt::magenta
+#define BUTTON_FROM_TEXT_COLOR Qt::black
+#define BUTTON_TO_BACKGROUND_COLOR Qt::yellow
+#define BUTTON_TO_TEXT_COLOR Qt::black
+#define BUTTON_DISABLED_BACKGROUND_COLOR Qt::darkGray
+#define BUTTON_DISABLED_TEXT_COLOR Qt::white
+#define BUTTON_ERROR_BACKGROUND_COLOR Qt::red
+#define BUTTON_ERROR_TEXT_COLOR Qt::black
+
+#define LOG_SCHEDULED_COLOR Qt::white
+#define LOG_PLAYING_COLOR Qt::green
+#define LOG_PAUSED_COLOR Qt::cyan
+#define LOG_NEXT_COLOR "#CCFFCC"
+#define LOG_FINISHED_COLOR Qt::gray
+#define LOG_EVERGREEN_COLOR "#008000"
+#define LOG_ERROR_COLOR Qt::red
+#define LOG_RELATIVE_TEXT_COLOR Qt::black
+#define LOG_HARDTIME_TEXT_COLOR Qt::blue
+
+/*
+ * Cart Label Box Colors
+ */
+#define BAR_UNCHANGED_TRANSITION_COLOR Qt::green
+#define BAR_UNCHANGED_STOPPING_COLOR Qt::red
+#define BAR_CHANGED_TRANSITION_COLOR Qt::yellow
+#define BAR_CHANGED_STOPPING_COLOR Qt::blue
+#define LABELBOX_BACKGROUND_COLOR Qt::white
+#define LABELBOX_MISSING_COLOR Qt::red
+#define LABELBOX_MARKER_COLOR Qt::cyan
+#define LABELBOX_CHAIN_COLOR Qt::magenta
+#define LABELBOX_EVERGREEN_COLOR "#008000"
+#define LABELBOX_TIMESCALE_COLOR Qt::green
+
+/*
+ * RDCartSlots Settings
+ */
+#define RDCARTSLOTS_MAX_ROWS 16
+#define RDCARTSLOTS_MAX_COLUMNS 4
+
+/*
+ * Custom MIME Types (for Drag and Drop)
+ */
+#define RDMIMETYPE_CART "application/rivendell-cart"
+
 
 #endif  // RD_H
