@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.cpp,v 1.61.2.3 2009/03/24 12:11:18 cvs Exp $
+//      $Id: rdcart.cpp,v 1.72.4.6 2013/12/31 15:06:00 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,10 +23,14 @@
 #ifndef WIN32
 #include <unistd.h>
 #include <syslog.h>
+#include <curl/curl.h>
 #endif  // WIN32
 
 #include <vector>
 
+#include <qstringlist.h>
+#include <qobject.h>
+
 #include <rd.h>
 #include <rdconf.h>
 #include <rdcart.h>
@@ -34,10 +38,36 @@
 #include <rdtextvalidator.h>
 #include <rdescape_string.h>
 #include <rdsystem.h>
+#include <rdxport_interface.h>
+#include <rdformpost.h>
+#include <rdweb.h>
+#include <rdstation.h>
+
+//
+// CURL Callbacks
+//
+size_t CartWriteCallback(void *ptr,size_t size,size_t nmemb,void *userdata)
+{
+  QString *xml=(QString *)userdata;
+  for(unsigned i=0;i<(size*nmemb);i++) {
+    *xml+=((const char *)ptr)[i];
+  }
+  return size*nmemb;
+}
+
 
 RDCart::RDCart(unsigned number)
 {
   cart_number=number;
+  metadata_changed=false;
+}
+
+
+RDCart::~RDCart()
+{
+  if(metadata_changed) {
+    writeTimestamp();
+  }
 }
 
 
@@ -79,8 +109,11 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
   QDate current_date=QDate::currentDate();
   QString datetime_str=QDateTime(current_date,time).
     toString("yyyy-MM-dd hh:mm:ss");
+  QString time_str=QDateTime(current_date,time).toString("hh:mm:ss");
 
-  if(type()==RDCart::Audio) {
+  //  if(type()==RDCart::Audio) {
+  switch(type()) {
+  case RDCart::Audio:
     sql=QString().sprintf("select CUT_NAME,WEIGHT,LOCAL_COUNTER\
                            from CUTS  where (((START_DATETIME<=\"%s\")&&\
                            (END_DATETIME>=\"%s\"))||\
@@ -91,13 +124,18 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
                            (LENGTH>0) order by LOCAL_COUNTER",
 			  (const char *)datetime_str,
 			  (const char *)datetime_str,
-			  (const char *)datetime_str,
-			  (const char *)datetime_str,
+			  (const char *)time_str,
+			  (const char *)time_str,
 	(const char *)RDGetShortDayNameEN(current_date.dayOfWeek()).upper(),
 			  cart_number);
     q=new RDSqlQuery(sql);
     cutname=GetNextCut(q);
     delete q;
+    break;
+
+  case RDCart::Macro:
+  case RDCart::All:
+    break;
   }
   if(cutname.isEmpty()) {   // No valid cuts, try the evergreen
 #ifndef WIN32
@@ -135,9 +173,10 @@ QString RDCart::groupName() const
 }
 
 
-void RDCart::setGroupName(const QString &name) const
+void RDCart::setGroupName(const QString &name)
 {
   SetRow("GROUP_NAME",name);
+  metadata_changed=true;
 }
 
 
@@ -148,9 +187,10 @@ RDCart::Type RDCart::type() const
 }
 
 
-void RDCart::setType(RDCart::Type type) const
+void RDCart::setType(RDCart::Type type)
 {
   SetRow("TYPE",(unsigned)type);
+  metadata_changed=true;
 }
 
 
@@ -160,9 +200,10 @@ QString RDCart::title() const
 }
 
 
-void RDCart::setTitle(const QString &title) const
+void RDCart::setTitle(const QString &title)
 {
   SetRow("TITLE",VerifyTitle(title));
+  metadata_changed=true;
 }
 
 
@@ -172,9 +213,10 @@ QString RDCart::artist() const
 }
 
 
-void RDCart::setArtist(const QString &artist) const
+void RDCart::setArtist(const QString &artist)
 {
   SetRow("ARTIST",artist);
+  metadata_changed=true;
 }
 
 
@@ -184,9 +226,10 @@ QString RDCart::album() const
 }
 
 
-void RDCart::setAlbum(const QString &album) const
+void RDCart::setAlbum(const QString &album)
 {
   SetRow("ALBUM",album);
+  metadata_changed=true;
 }
 
 
@@ -201,9 +244,10 @@ QDate RDCart::year() const
 }
 
 
-void RDCart::setYear(const QDate &date) const
+void RDCart::setYear(const QDate &date)
 {
   SetRow("YEAR",date);
+  metadata_changed=true;
 }
 
 
@@ -245,9 +289,10 @@ void RDCart::updateSchedCodes(const QString &add_codes,const QString &remove_cod
   SetRow("SCHED_CODES",save_codes);
 }	
 
-void RDCart::setYear() const
+void RDCart::setYear()
 {
   SetRow("YEAR");
+  metadata_changed=true;
 }
 
 
@@ -257,9 +302,23 @@ QString RDCart::label() const
 }
 
 
-void RDCart::setLabel(const QString &label) const
+void RDCart::setLabel(const QString &label)
 {
   SetRow("LABEL",label);
+  metadata_changed=true;
+}
+
+
+QString RDCart::conductor() const
+{
+  return RDGetSqlValue("CART","NUMBER",cart_number,"CONDUCTOR").toString();
+}
+
+
+void RDCart::setConductor(const QString &cond)
+{
+  SetRow("CONDUCTOR",cond);
+  metadata_changed=true;
 }
 
 
@@ -269,9 +328,10 @@ QString RDCart::client() const
 }
 
 
-void RDCart::setClient(const QString &client) const
+void RDCart::setClient(const QString &client)
 {
   SetRow("CLIENT",client);
+  metadata_changed=true;
 }
 
 
@@ -281,9 +341,10 @@ QString RDCart::agency() const
 }
 
 
-void RDCart::setAgency(const QString &agency) const
+void RDCart::setAgency(const QString &agency)
 {
   SetRow("AGENCY",agency);
+  metadata_changed=true;
 }
 
 
@@ -294,9 +355,10 @@ QString RDCart::publisher() const
 }
 
 
-void RDCart::setPublisher(const QString &publisher) const
+void RDCart::setPublisher(const QString &publisher)
 {
   SetRow("PUBLISHER",publisher);
+  metadata_changed=true;
 }
 
 
@@ -307,9 +369,10 @@ QString RDCart::composer() const
 }
 
 
-void RDCart::setComposer(const QString &composer) const
+void RDCart::setComposer(const QString &composer)
 {
   SetRow("COMPOSER",composer);
+  metadata_changed=true;
 }
 
 
@@ -320,9 +383,36 @@ QString RDCart::userDefined() const
 }
 
 
-void RDCart::setUserDefined(const QString &string) const
+void RDCart::setUserDefined(const QString &string)
 {
   SetRow("USER_DEFINED",string);
+  metadata_changed=true;
+}
+
+
+QString RDCart::songId() const
+{
+  return RDGetSqlValue("CART","NUMBER",cart_number,"SONG_ID").toString();
+}
+
+
+void RDCart::setSongId(const QString &id)
+{
+  SetRow("SONG_ID",id);
+  metadata_changed=true;
+}
+
+
+unsigned RDCart::beatsPerMinute() const
+{
+  return RDGetSqlValue("CART","NUMBER",cart_number,"BPM").toUInt();
+}
+
+
+void RDCart::setBeatsPerMinute(unsigned bpm)
+{
+  SetRow("BPM",bpm);
+  metadata_changed=true;
 }
 
 
@@ -336,6 +426,20 @@ RDCart::UsageCode RDCart::usageCode() const
 void RDCart::setUsageCode(RDCart::UsageCode code)
 {
   SetRow("USAGE_CODE",(int)code);
+  metadata_changed=true;
+}
+
+
+QString RDCart::notes() const
+{
+  return RDGetSqlValue("CART","NUMBER",cart_number,"NOTES").toString();
+}
+
+
+void RDCart::setNotes(const QString &notes)
+{
+  SetRow("NOTES",notes);
+  metadata_changed=true;
 }
 
 
@@ -346,9 +450,10 @@ unsigned RDCart::forcedLength() const
 }
 
 
-void RDCart::setForcedLength(unsigned length) const
+void RDCart::setForcedLength(unsigned length)
 {
   SetRow("FORCED_LENGTH",length);
+  metadata_changed=true;
 }
 
 
@@ -371,46 +476,56 @@ unsigned RDCart::calculateAverageLength(unsigned *max_dev) const
   unsigned count=0;
   unsigned high=0;
   unsigned low=0xFFFFFFFF;
-  unsigned avg;
+  unsigned avg=0;
   unsigned weight;
   QDateTime end_datetime;
+  QString sql;
+  RDSqlQuery *q;
 
-  QString sql=QString().sprintf("select LENGTH, WEIGHT,END_DATETIME from CUTS\
-                                 where (CART_NUMBER=%u)&&(LENGTH>0)",
-				cart_number);
-  RDSqlQuery *q=new RDSqlQuery(sql);
-  while(q->next()) {
-    weight = q->value(1).toUInt();
-    end_datetime = q->value(2).toDateTime();
-    if (end_datetime.isValid() && (end_datetime <QDateTime::currentDateTime ())){
-      // This cut has expired, it is no more, set its weight to zero.
-      weight = 0;
+  switch(type()) {
+  case RDCart::Audio:
+    sql=QString().sprintf("select LENGTH, WEIGHT,END_DATETIME from CUTS\
+                           where (CART_NUMBER=%u)&&(LENGTH>0)",
+			  cart_number);
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      weight = q->value(1).toUInt();
+      end_datetime = q->value(2).toDateTime();
+      if (end_datetime.isValid() && (end_datetime <QDateTime::currentDateTime ())){
+	// This cut has expired, it is no more, set its weight to zero.
+	weight = 0;
+      }
+      total+=(q->value(0).toUInt() * weight);
+      if((weight) && (q->value(0).toUInt()>high)) {
+	high=q->value(0).toUInt();
+      }
+      if((weight) && (q->value(0).toUInt()<low)) {
+	low=q->value(0).toUInt();
+      }
+      count += weight;    
     }
-    total+=(q->value(0).toUInt() * weight);
-    if((weight) && (q->value(0).toUInt()>high)) {
-      high=q->value(0).toUInt();
-    }
-    if((weight) && (q->value(0).toUInt()<low)) {
-      low=q->value(0).toUInt();
-    }
-    count += weight;    
-  }
-  delete q;
-  if(count==0) {
-    avg=0;
-    low=0;
-    high=0;
-  }
-  else {
-    avg=total/count;
-  }
-  if(max_dev!=NULL) {
-    if((high-avg)>(avg-low)) {
-      *max_dev=high-avg;
+    delete q;
+    if(count==0) {
+      avg=0;
+      low=0;
+      high=0;
     }
     else {
-      *max_dev=avg-low;
+      avg=total/count;
     }
+    if(max_dev!=NULL) {
+      if((high-avg)>(avg-low)) {
+	*max_dev=high-avg;
+      }
+      else {
+	*max_dev=avg-low;
+      }
+    }
+    break;
+
+  case RDCart::Macro:
+  case RDCart::All:
+    break;
   }
   return avg;
 }
@@ -519,15 +634,17 @@ QDateTime RDCart::startDateTime() const
 }
 
 
-void RDCart::setStartDateTime(const QDateTime &time) const
+void RDCart::setStartDateTime(const QDateTime &time)
 {
   SetRow("START_DATETIME",time);
+  metadata_changed=true;
 }
 
 
-void RDCart::setStartDateTime() const
+void RDCart::setStartDateTime()
 {
   SetRow("START_DATETIME");
+  metadata_changed=true;
 }
 
 
@@ -543,15 +660,17 @@ QDateTime RDCart::endDateTime() const
 }
 
 
-void RDCart::setEndDateTime(const QDateTime &time) const
+void RDCart::setEndDateTime(const QDateTime &time)
 {
   SetRow("END_DATETIME",time);
+  metadata_changed=true;
 }
 
 
-void RDCart::setEndDateTime() const
+void RDCart::setEndDateTime()
 {
   SetRow("END_DATETIME");
+  metadata_changed=true;
 }
 
 
@@ -562,9 +681,10 @@ bool RDCart::enforceLength() const
 }
 
 
-void RDCart::setEnforceLength(bool state) const
+void RDCart::setEnforceLength(bool state)
 {
   SetRow("ENFORCE_LENGTH",RDYesNo(state));
+  metadata_changed=true;
 }
 
 
@@ -618,13 +738,14 @@ void RDCart::setMacros(const QString &cmds) const
 }
 
 
-void RDCart::getMetadata(RDWaveData *data)
+void RDCart::getMetadata(RDWaveData *data) const
 {
   QString sql;
   RDSqlQuery *q;
 
   sql=QString().sprintf("select TITLE,ARTIST,ALBUM,YEAR,LABEL,CLIENT,\
-                         AGENCY,PUBLISHER,COMPOSER,USER_DEFINED\
+                         AGENCY,PUBLISHER,COMPOSER,USER_DEFINED,\
+                         CONDUCTOR,SONG_ID,BPM \
                          from CART where NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   if(q->first()) {
@@ -638,13 +759,16 @@ void RDCart::getMetadata(RDWaveData *data)
     data->setPublisher(q->value(7).toString());
     data->setComposer(q->value(8).toString());
     data->setUserDefined(q->value(9).toString());
+    data->setConductor(q->value(10).toString());
+    data->setTmciSongId(q->value(11).toString());
+    data->setBeatsPerMinute(q->value(12).toUInt());
     data->setMetadataFound(true);
   }
   delete q;
 }
 
 
-void RDCart::setMetadata(RDWaveData *data)
+void RDCart::setMetadata(const RDWaveData *data)
 {
   QString sql="update CART set ";
   if(!data->title().isEmpty()) {
@@ -666,6 +790,10 @@ void RDCart::setMetadata(RDWaveData *data)
     sql+=QString().sprintf("LABEL=\"%s\",",(const char *)
 			   RDEscapeString(data->label()).utf8());
   }
+  if(!data->conductor().isEmpty()) {
+    sql+=QString().sprintf("CONDUCTOR=\"%s\",",(const char *)
+			   RDEscapeString(data->conductor()).utf8());
+  }
   if(!data->client().isEmpty()) {
     sql+=QString().sprintf("CLIENT=\"%s\",",(const char *)
 			   RDEscapeString(data->client()).utf8());
@@ -686,22 +814,152 @@ void RDCart::setMetadata(RDWaveData *data)
     sql+=QString().sprintf("USER_DEFINED=\"%s\",",(const char *)
 			   RDEscapeString(data->userDefined()).utf8());
   }
+  if(!data->tmciSongId().isEmpty()) {
+    sql+=QString().sprintf("SONG_ID=\"%s\",",(const char *)
+			   RDEscapeString(data->tmciSongId()).utf8());
+  }
+  if(data->beatsPerMinute()>0) {
+    sql+=QString().sprintf("BPM=%u,",data->beatsPerMinute());
+  }
   if(sql.right(1)==",") {
     sql=sql.left(sql.length()-1);
     sql+=QString().sprintf(" where NUMBER=%u",cart_number);
     RDSqlQuery *q=new RDSqlQuery(sql);
     delete q;
   }
+  metadata_changed=true;
 }
 
 
-void RDCart::updateLength() const
+bool RDCart::validateLengths(int len) const
+{
+  int maxlen=(int)(RD_TIMESCALE_MAX*(double)len);
+  int minlen=(int)(RD_TIMESCALE_MIN*(double)len);
+  QString sql=QString().sprintf("select LENGTH from CUTS where CART_NUMBER=%u",
+				cart_number);
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+    if((q->value(0).toInt()>maxlen)||(q->value(0).toInt()<minlen)) {
+      delete q;
+      return false;
+    }
+  }
+  delete q;
+
+  return true;
+}
+
+
+QString RDCart::xml(bool include_cuts) const
+{
+#ifdef WIN32
+  return QString();
+#else
+  QString sql;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
+  QString ret="";
+  RDCut *cut;
+  QStringList mlist;
+
+  sql=QString().sprintf("select TYPE,GROUP_NAME,TITLE,ARTIST,ALBUM,YEAR,\
+                         LABEL,CLIENT,AGENCY,PUBLISHER,COMPOSER,USER_DEFINED,\
+                         USAGE_CODE,FORCED_LENGTH,AVERAGE_LENGTH,\
+                         LENGTH_DEVIATION,AVERAGE_SEGUE_LENGTH,\
+                         AVERAGE_HOOK_LENGTH,CUT_QUANTITY,LAST_CUT_PLAYED,\
+                         VALIDITY,\
+                         ENFORCE_LENGTH,ASYNCRONOUS,OWNER,METADATA_DATETIME \
+                         from CART where NUMBER=%u",cart_number);
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    ret+="<cart>\n";
+    ret+="  "+RDXmlField("number",cart_number);
+    switch((RDCart::Type)q->value(0).toUInt()) {
+    case RDCart::Audio:
+      ret+="  "+RDXmlField("type","audio");
+      break;
+
+    case RDCart::Macro:
+      ret+="  "+RDXmlField("type","macro");
+      break;
+
+    case RDCart::All:
+      break;
+    }
+    ret+="  "+RDXmlField("groupName",q->value(1).toString());
+    ret+="  "+RDXmlField("title",q->value(2).toString());
+    ret+="  "+RDXmlField("artist",q->value(3).toString());
+    ret+="  "+RDXmlField("album",q->value(4).toString());
+    ret+="  "+RDXmlField("year",q->value(5).toDate().toString("yyyy"));
+    ret+="  "+RDXmlField("label",q->value(6).toString());
+    ret+="  "+RDXmlField("client",q->value(7).toString());
+    ret+="  "+RDXmlField("agency",q->value(8).toString());
+    ret+="  "+RDXmlField("publisher",q->value(9).toString());
+    ret+="  "+RDXmlField("composer",q->value(10).toString());
+    ret+="  "+RDXmlField("userDefined",q->value(11).toString());
+    ret+="  "+RDXmlField("usageCode",q->value(12).toInt());
+    ret+="  "+RDXmlField("forcedLength",
+			 RDGetTimeLength(q->value(13).toUInt(),true));
+    ret+="  "+RDXmlField("averageLength",
+			 RDGetTimeLength(q->value(14).toUInt(),true));
+    ret+="  "+RDXmlField("lengthDeviation",
+			 RDGetTimeLength(q->value(15).toUInt(),true));
+    ret+="  "+RDXmlField("averageSegueLenth",
+			 RDGetTimeLength(q->value(16).toUInt(),true));
+    ret+="  "+RDXmlField("averageHookLength",
+			 RDGetTimeLength(q->value(17).toUInt(),true));
+    ret+="  "+RDXmlField("cutQuantity",q->value(18).toUInt());
+    ret+="  "+RDXmlField("lastCutPlayed",q->value(19).toUInt());
+    ret+="  "+RDXmlField("validity",q->value(20).toUInt());
+    ret+="  "+RDXmlField("enforceLength",RDBool(q->value(21).toString()));
+    ret+="  "+RDXmlField("asyncronous",RDBool(q->value(22).toString()));
+    ret+="  "+RDXmlField("owner",q->value(23).toString());
+    ret+="  "+RDXmlField("metadataDatetime",q->value(24).toDateTime());
+      switch(type()) {
+      case RDCart::Audio:
+	if(include_cuts) {
+	  ret+="<cutList>\n";
+	  sql=QString().sprintf("select CUT_NAME from CUTS where CART_NUMBER=%u",
+				cart_number);
+	  q1=new RDSqlQuery(sql);
+	  while(q1->next()) {
+	    cut=new RDCut(q1->value(0).toString());
+	    ret+=cut->xml();
+	    delete cut;
+	  }
+	  delete q1;
+	  ret+="</cutList>\n";
+	}
+	break;
+
+      case RDCart::Macro:
+	mlist=mlist.split("!",macros());
+	ret+="  <macroList>\n";
+	for(unsigned i=0;i<mlist.size();i++) {
+	  ret+=QString().sprintf("    <macro%d>",i)+mlist[i]+
+	    QString().sprintf("!</macro%d>\n",i);
+	}
+	ret+="  </macroList>\n";
+	break;
+	
+      case RDCart::All:
+	break;
+      }
+      ret+="</cart>\n";
+  }
+  delete q;
+  return ret;
+#endif  // WIN32
+}
+
+
+void RDCart::updateLength()
 {
   updateLength(enforceLength(),forcedLength());
 }
 
 
-void RDCart::updateLength(bool enforce_length,unsigned length) const
+void RDCart::updateLength(bool enforce_length,unsigned length)
 {
   //
   // Update Length
@@ -770,6 +1028,9 @@ void RDCart::updateLength(bool enforce_length,unsigned length) const
   QDateTime start_datetime;
   QDateTime end_datetime;
   RDSqlQuery *q1;
+  QDateTime valid_until;
+  bool dates_valid=true;
+
   sql=QString().sprintf("select CUT_NAME,START_DAYPART,END_DAYPART,LENGTH,\
                          SUN,MON,TUE,WED,THU,FRI,SAT,EVERGREEN,\
                          START_DATETIME,END_DATETIME from CUTS\
@@ -786,6 +1047,9 @@ void RDCart::updateLength(bool enforce_length,unsigned length) const
     if((int)cut_validity>(int)cart_validity) {
       cart_validity=(RDCart::Validity)cut_validity;
     }
+    if((cut_validity!=RDCut::NeverValid)&&(q->value(13).isNull())) {
+      dates_valid=false;
+    }
     if(!q->value(12).isNull()) {
       if((start_datetime>q->value(12).toDateTime())||
 	 start_datetime.isNull()) {
@@ -812,18 +1076,24 @@ void RDCart::updateLength(bool enforce_length,unsigned length) const
   if(evergreen) {  // Promote to Evergreen?
     cart_validity=RDCart::EvergreenValid;
   }
+
+  //
+  // Set start/end datetimes
+  //
   sql="update CART set ";
-  if(start_datetime.isNull()) {
+  if(start_datetime.isNull()||(!dates_valid)) {
     sql+="START_DATETIME=NULL,";
   }
   else {
-    sql+="START_DATETIME=NULL,";
+    sql+=QString().sprintf("START_DATETIME=\"%s\",",
+		(const char *)start_datetime.toString("yyyy-MM-dd hh:mm:ss"));
   }
-  if(end_datetime.isNull()) {
+  if(end_datetime.isNull()||(!dates_valid)) {
     sql+="END_DATETIME=NULL,";
   }
   else {
-    sql+="END_DATETIME=NULL,";
+    sql+=QString().sprintf("END_DATETIME=\"%s\",",
+		(const char *)end_datetime.toString("yyyy-MM-dd hh:mm:ss"));
   }
   sql+=QString().sprintf("VALIDITY=%u where NUMBER=%u",
 			 cart_validity,cart_number);
@@ -842,23 +1112,40 @@ void RDCart::resetRotation() const
 }
 
 
-int RDCart::addCut(unsigned format,unsigned samprate,
-		   unsigned bitrate,unsigned chans) const
+void RDCart::writeTimestamp()
+{
+  QString sql;
+  RDSqlQuery *q;
+  sql=QString().sprintf("update CART set METADATA_DATETIME=now() \
+                         where NUMBER=%u",cart_number);
+  q=new RDSqlQuery(sql);
+  delete q;
+  metadata_changed=false;
+}
+
+
+int RDCart::addCut(unsigned format,unsigned bitrate,unsigned chans,
+		   const QString &isci,QString desc)
 {
   RDSqlQuery *q;
   QString sql;
+  int next;
 
-  int next=GetNextFreeCut();
+  if((next=GetNextFreeCut())<0) {
+    return -1;
+  }
   QString next_name=QString().sprintf("%06d_%03d",cart_number,next);
+  if(desc.isEmpty()) {
+    desc=QString().sprintf("Cut %03d",next);
+  }
   sql=QString().sprintf("insert into CUTS set CUT_NAME=\"%s\",\
-                         CART_NUMBER=%d,DESCRIPTION=\"Cut %03d\",LENGTH=0,\
-                         CODING_FORMAT=%d,SAMPLE_RATE=%d,BIT_RATE=%d,\
-                         CHANNELS=%d",
+                         CART_NUMBER=%d,ISCI=\"%s\",DESCRIPTION=\"%s\",\
+                         LENGTH=0,CODING_FORMAT=%d,BIT_RATE=%d,CHANNELS=%d",
 			(const char *)next_name,
 			cart_number,
-			next,
+			(const char *)RDEscapeString(isci),
+			(const char *)RDEscapeString(desc),
 			format,
-			samprate,
 			bitrate,
 			chans);
   q=new RDSqlQuery(sql);
@@ -867,11 +1154,12 @@ int RDCart::addCut(unsigned format,unsigned samprate,
   setCutQuantity(cutQuantity()+1);
   updateLength();
   resetRotation();
+  metadata_changed=true;
   return next;
 }
 
 
-void RDCart::removeAllCuts()
+bool RDCart::removeAllCuts(RDStation *station,RDUser *user,RDConfig *config)
 {
   QString sql;
   RDSqlQuery *q;
@@ -880,16 +1168,22 @@ void RDCart::removeAllCuts()
 			cart_number);
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    removeCut(q->value(0).toString());
+    if(!removeCut(station,user,q->value(0).toString(),config)) {
+      delete q;
+      return false;
+    }
   }
   delete q;
+  metadata_changed=true;
+  return true;
 }
 
 
-void RDCart::removeCut(const QString &cutname)
+bool RDCart::removeCut(RDStation *station,RDUser *user,const QString &cutname,
+		       RDConfig *config)
 {
   if(!exists()) {
-    return;
+    return true;
   }
 
   QString sql;
@@ -897,48 +1191,121 @@ void RDCart::removeCut(const QString &cutname)
   QString filename;
 
   filename = RDCut::pathName(cutname); 
-  unlink(filename);
+  if(!removeCutAudio(station,user,cutname,config)) {
+    return false;
+  }
+  sql=QString().sprintf("delete from REPL_CUT_STATE where CUT_NAME=\"%s\"",
+			(const char *)cutname);
+  q=new RDSqlQuery(sql);
+  delete q;
   sql=QString().sprintf("delete from CUTS where CUT_NAME=\"%s\"",
 			(const char *)cutname);
   q=new RDSqlQuery(sql);
   delete q;
   setCutQuantity(cutQuantity()-1);
+  metadata_changed=true;
+
+  return true;
 }
 
 
-bool RDCart::create(const QString &groupname,RDCart::Type type) const
+bool RDCart::removeCutAudio(RDStation *station,RDUser *user,
+			    const QString &cutname,RDConfig *config) const
+{
+  bool ret=true;
+#ifndef WIN32
+  CURL *curl=NULL;
+  long response_code=0;
+  char url[1024];
+  QString xml="";
+
+  if(user==NULL) { 
+    unlink(RDCut::pathName(cutname));
+    unlink(RDCut::pathName(cutname)+".energy");
+  }
+  else {
+    //
+    // Generate POST Data
+    //
+    QString post=QString().
+      sprintf("COMMAND=%d&LOGIN_NAME=%s&PASSWORD=%s&CART_NUMBER=%u&CUT_NUMBER=%u",
+	      RDXPORT_COMMAND_DELETEAUDIO,
+	      (const char *)RDFormPost::urlEncode(user->name()),
+	      (const char *)RDFormPost::urlEncode(user->password()),
+	      cart_number,
+	      cutname.right(3).toUInt());
+    if((curl=curl_easy_init())==NULL) {
+      return false;
+    }
+    //
+    // Write out URL as a C string before passing to curl_easy_setopt(), 
+    // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
+    // error.
+    //
+    strncpy(url,station->webServiceUrl(config),1024);
+    curl_easy_setopt(curl,CURLOPT_URL,url);
+    curl_easy_setopt(curl,CURLOPT_POST,1);
+    curl_easy_setopt(curl,CURLOPT_POSTFIELDS,(const char *)post);
+    curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
+    curl_easy_setopt(curl,CURLOPT_WRITEFUNCTION,CartWriteCallback);
+    curl_easy_setopt(curl,CURLOPT_WRITEDATA,&xml);
+    ret&=curl_easy_perform(curl)==0;
+    curl_easy_getinfo(curl,CURLINFO_RESPONSE_CODE,&response_code);
+    ret&=response_code==200;
+    curl_easy_cleanup(curl);
+  }
+#endif  // WIN32
+  return ret;
+}
+
+
+bool RDCart::create(const QString &groupname,RDCart::Type type)
 {
   QString sql=QString().sprintf("insert into CART set NUMBER=%d,TYPE=%d,\
-                                 GROUP_NAME=\"%s\"",cart_number,type,
-				(const char *)groupname);
+                                 GROUP_NAME=\"%s\",TITLE=\"%s\"",
+				cart_number,type,
+				(const char *)RDEscapeString(groupname),
+				(const char *)
+				RDEscapeString(RD_DEFAULT_CART_TITLE));
   RDSqlQuery *q=new RDSqlQuery(sql);
   bool ret=q->isActive();
   delete q;
+  metadata_changed=true;
 
   return ret;
 }
 
 
-void RDCart::remove() const
+bool RDCart::remove(RDStation *station,RDUser *user,RDConfig *config) const
 {
   QString sql;
   RDSqlQuery *q;
 
   if(type()==RDCart::Audio) {
-    sql=QString().sprintf("select CUT_NAME from CUTS where CART_NUMBER=%u",
+    sql=QString().sprintf("select CUT_NAME from CUTS \
+                           where CART_NUMBER=%u",
 			  cart_number);
     q=new RDSqlQuery(sql);
     while(q->next()) {
-      unlink(RDCut::pathName(QString(q->value(0).toString())).ascii()); 
+      if(!removeCutAudio(station,user,q->value(0).toString(),config)) {
+	delete q;
+	return false;
+      }
     }
     delete q;
     sql=QString().sprintf("delete from CUTS where CART_NUMBER=%u",cart_number);
     q=new RDSqlQuery(sql);
     delete q;
   }
+  sql=QString().sprintf("delete from REPL_CART_STATE where CART_NUMBER=%u",
+			cart_number);
+  q=new RDSqlQuery(sql);
+  delete q;
   sql=QString().sprintf("delete from CART where NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   delete q;
+
+  return true;
 }
 
 
@@ -956,12 +1323,12 @@ QString RDCart::playOrderText(RDCart::PlayOrder order)
 {
   switch(order) {
       case RDCart::Sequence:
-	return QT_TR_NOOP("Sequentially");
+	return QObject::tr("Sequentially");
 
       case RDCart::Random:
-	return QT_TR_NOOP("Randomly");
+	return QObject::tr("Randomly");
   }
-  return QString QT_TR_NOOP("Unknown");
+  return QObject::tr("Unknown");
 }
 
 
@@ -969,28 +1336,51 @@ QString RDCart::usageText(RDCart::UsageCode usage)
 {
   switch(usage) {
       case RDCart::UsageFeature:
-	return QT_TR_NOOP("Feature");
+	return QObject::tr("Feature");
 
       case RDCart::UsageOpen:
-	return QT_TR_NOOP("Theme Open");
+	return QObject::tr("Theme Open");
 
       case RDCart::UsageClose:
-	return QT_TR_NOOP("Theme Close");
+	return QObject::tr("Theme Close");
 
       case RDCart::UsageTheme:
-	return QT_TR_NOOP("Theme Open/Close");
+	return QObject::tr("Theme Open/Close");
 
       case RDCart::UsageBackground:
-	return QT_TR_NOOP("Background");
+	return QObject::tr("Background");
 
       case RDCart::UsagePromo:
-	return QT_TR_NOOP("Commercial/Jingle/Promo");
+	return QObject::tr("Commercial/Jingle/Promo");
 
       case RDCart::UsageLast:
-	return QT_TR_NOOP("Unknown");  
+	return QObject::tr("Unknown");  
 	break;
   }
-  return QT_TR_NOOP("Unknown");  
+  return QObject::tr("Unknown");  
+}
+
+
+QString RDCart::typeText(RDCart::Type type)
+{
+  QString ret=QObject::tr("Unknown");
+
+  switch(type) {
+  case RDCart::All:
+    ret=QObject::tr("All");
+    break;
+
+  case RDCart::Audio:
+    ret=QObject::tr("Audio");
+    break;
+
+  case RDCart::Macro:
+    ret=QObject::tr("Macro");
+    break;
+
+  }
+
+  return ret;
 }
 
 
@@ -1008,28 +1398,6 @@ QString RDCart::GetNextCut(RDSqlQuery *q) const
       cutname=q->value(0).toString();
     }
   }
-#ifndef WIN32
-/*  Random rotation disabled -- FFG 4/2/2008
-  switch(playOrder()) {
-      case RDCart::Random:
-	q->seek(-1);
-	while(q->next()) {
-	  if((q->value(2).toDouble()/q->value(1).toDouble())==play_ratio) {
-	    eligibles.push_back(q->at());
-	  }
-	}
-	if(eligibles.size()>0) {
-	  q->seek(eligibles[(int)((double)eligibles.size()*
-				  (double)random()/RAND_MAX)]);
-	  cutname=q->value(0).toString();
-	}
-	break;
-
-      default:
-	break;
-  }
-*/
-#endif  // WIN32
   return cutname;
 }
 
@@ -1038,18 +1406,24 @@ int RDCart::GetNextFreeCut() const
 {
   RDSqlQuery *q;
   QString sql;
-  unsigned num=1;
 
   sql=QString().sprintf("select CUT_NAME from CUTS where CART_NUMBER=%d\
                          order by CUT_NAME",
 			cart_number);
   q=new RDSqlQuery(sql);
-  if(q->last()) {
-    sscanf(((const char *)q->value(0).toString())+7,"%d",&num);
-    num++;
+  for(int i=1;i<=RD_MAX_CUT_NUMBER;i++) {
+    if(q->next()) {
+      if(q->value(0).toString()!=RDCut::cutName(cart_number,i)) {
+	delete q;
+	return i;
+      }
+    }
+    else {
+      delete q;
+      return i;
+    }
   }
-  delete q;
-  return num;
+  return -1;
 }
 
 
