@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2012 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcartslot.cpp,v 1.13.2.10 2012/11/30 16:14:59 cvs Exp $
+//      $Id: rdcartslot.cpp,v 1.13.2.16 2013/12/30 19:56:12 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,24 +23,28 @@
 #include <qpainter.h>
 #include <qbitmap.h>
 
+#include "rdconfig.h"
 #include "rdconf.h"
 #include "rdescape_string.h"
 #include "rdcart.h"
 #include "rdcartslot.h"
 
 RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
-		       RDListSvcs *svcs_dialog,RDSlotDialog *slot_dialog,
-		       RDCartDialog *cart_dialog,const QString &caption,
-		       QWidget *parent)
+		       RDConfig *config,RDListSvcs *svcs_dialog,
+		       RDSlotDialog *slot_dialog,RDCartDialog *cart_dialog,
+		       RDCueEditDialog *cue_dialog,
+		       const QString &caption,QWidget *parent)
   : QWidget(parent)
 {
   slot_number=slotnum;
   slot_ripc=ripc;
   slot_cae=cae;
   slot_station=station;
+  slot_config=config;
   slot_svcs_dialog=svcs_dialog;
   slot_slot_dialog=slot_dialog;
   slot_cart_dialog=cart_dialog;
+  slot_cue_dialog=cue_dialog;
   slot_caption=caption;
 
   slot_svc_names=NULL;
@@ -84,6 +88,7 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
 	  this,SLOT(stateChangedData(int,RDPlayDeck::State)));
   connect(slot_deck,SIGNAL(position(int,int)),
 	  this,SLOT(positionData(int,int)));
+  connect(slot_deck,SIGNAL(hookEnd(int)),this,SLOT(hookEndData(int)));
   connect(slot_cae,SIGNAL(timescalingSupported(int,bool)),
 	  this,SLOT(timescalingSupportedData(int,bool)));
 
@@ -99,12 +104,14 @@ RDCartSlot::RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
   //
   // Slot Box
   //
-  slot_box=new RDSlotBox(this);
-  slot_box->setBarMode(RDSlotBox::Stopping);
+  slot_box=new RDSlotBox(slot_deck,this);
+  slot_box->setBarMode(false);
   slot_box->setGeometry(5+sizeHint().height(),0,
 			slot_box->sizeHint().width(),
 			slot_box->sizeHint().height());
-  connect(slot_box,SIGNAL(doubleClicked()),this,SLOT(loadData()));
+  connect(slot_box,SIGNAL(doubleClicked()),this,SLOT(doubleClickedData()));
+  connect(slot_box,SIGNAL(cartDropped(unsigned)),
+	  this,SLOT(cartDroppedData(unsigned)));
 
   //
   // Load Button
@@ -194,6 +201,7 @@ void RDCartSlot::updateOptions()
   case RDSlotOptions::LastMode:
     break;
   }
+  slot_box->setMode(slot_options->mode());
   slot_options->save();
   if(slot_logline->cartNumber()!=0) {
     load(slot_logline->cartNumber());
@@ -223,6 +231,7 @@ void RDCartSlot::setCart(RDCart *cart,int break_len)
     slot_logline->setTimescalingActive(slot_timescaling_active);
     slot_logline->setEvent(0,RDLogLine::Play,true,break_len);
     slot_box->setCart(slot_logline);
+    slot_box->setBarMode(false);
   }
 }
 
@@ -268,8 +277,14 @@ bool RDCartSlot::play()
   bool ret=false;
   if(slot_logline->cartNumber()!=0) {
     if(slot_deck->setCart(slot_logline,true)) {
-      slot_deck->play(0);
-      LogPlayout(RDAirPlayConf::TrafficStart);
+      if(slot_options->hookMode()&&(slot_logline->hookStartPoint()>=0)) {
+	slot_deck->playHook();
+      }
+      else {
+	slot_deck->play(slot_logline->playPosition());
+      }
+      slot_logline->setStartTime(RDLogLine::Actual,QTime::currentTime());
+      //      LogPlayout(RDAirPlayConf::TrafficStart);
       ret=true;
     }
   }
@@ -289,7 +304,7 @@ bool RDCartSlot::stop()
   if(slot_logline->cartNumber()!=0) {
     slot_stop_requested=true;
     slot_deck->stop();
-    LogPlayout(RDAirPlayConf::TrafficStop);
+    //    LogPlayout(RDAirPlayConf::TrafficStop);
     ret=true;
   }
   return ret;
@@ -395,6 +410,20 @@ void RDCartSlot::startData()
 }
 
 
+void RDCartSlot::doubleClickedData()
+{
+  if(slot_logline->cartNumber()==0) {
+    loadData();
+  }
+  else {
+    if(slot_cue_dialog->exec(slot_logline)==0) {
+      slot_box->setBarMode(true);
+      slot_box->setCart(slot_logline);
+    }
+  }
+}
+
+
 void RDCartSlot::loadData()
 {
   int cartnum;
@@ -447,6 +476,7 @@ void RDCartSlot::stateChangedData(int id,RDPlayDeck::State state)
 
   switch(state) {
   case RDPlayDeck::Playing:
+    LogPlayout(state);
     slot_start_button->
       setEnabled(slot_options->mode()==RDSlotOptions::CartDeckMode);
     slot_start_button->setPalette(slot_playing_color);
@@ -456,6 +486,7 @@ void RDCartSlot::stateChangedData(int id,RDPlayDeck::State state)
 
   case RDPlayDeck::Stopped:
   case RDPlayDeck::Finished:
+    LogPlayout(state);
     slot_start_button->
       setEnabled(slot_options->mode()==RDSlotOptions::CartDeckMode);
     slot_start_button->setPalette(slot_ready_color);
@@ -463,6 +494,7 @@ void RDCartSlot::stateChangedData(int id,RDPlayDeck::State state)
     slot_options_button->setEnabled(true);
     slot_box->setTimer(0);
     slot_box->updateMeters(lvls);
+    slot_box->setCart(slot_logline);
     switch(slot_options->mode()) {
     case RDSlotOptions::CartDeckMode:
       if(!slot_stop_requested) {
@@ -500,7 +532,7 @@ void RDCartSlot::stateChangedData(int id,RDPlayDeck::State state)
 	unload();
 	slot_box->setService(slot_svcname);
 	slot_box->setStatusLine(tr("Waiting for break..."));
-	LogPlayout(RDAirPlayConf::TrafficFinish);
+	//	LogPlayout(RDAirPlayConf::TrafficFinish);
       }
       break;
 
@@ -524,6 +556,14 @@ void RDCartSlot::positionData(int id,int msecs)
 }
 
 
+void RDCartSlot::hookEndData(int id)
+{
+  if(slot_options->hookMode()) {
+    stop();
+  }
+}
+
+
 void RDCartSlot::timescalingSupportedData(int card,bool state)
 {
   if(card==slot_options->card()) {
@@ -532,8 +572,21 @@ void RDCartSlot::timescalingSupportedData(int card,bool state)
 }
 
 
+void RDCartSlot::cartDroppedData(unsigned cartnum)
+{
+  if(cartnum==0) {
+    unload();
+  }
+  else {
+    load(cartnum);
+  }
+}
+
+
 void RDCartSlot::InitializeOptions()
 {
+  slot_svcname=slot_options->service();
+
   switch(slot_options->mode()) {
   case RDSlotOptions::CartDeckMode:
     if(slot_options->cartNumber()>0) {
@@ -542,7 +595,6 @@ void RDCartSlot::InitializeOptions()
     break;
 
   case RDSlotOptions::BreakawayMode:
-    slot_svcname=slot_options->service();
     slot_box->setService(slot_svcname);
     slot_box->setStatusLine(tr("Waiting for break..."));
     break;
@@ -592,17 +644,20 @@ void RDCartSlot::SetInput(bool state)
 }
 
 
-void RDCartSlot::LogPlayout(RDAirPlayConf::TrafficAction action)
+void RDCartSlot::LogPlayout(RDPlayDeck::State state)
 {
-  if(action==RDAirPlayConf::TrafficStart) {
+  if(state==RDPlayDeck::Playing) {
     RDCut *cut=new RDCut(slot_logline->cutName());
     cut->logPlayout();
     delete cut;
-    action=RDAirPlayConf::TrafficStart;
   }
-  if(slot_options->mode()!=RDSlotOptions::BreakawayMode) {
+  if((state!=RDPlayDeck::Stopped)&&(state!=RDPlayDeck::Finished)) {
     return;
   }
+  RDAirPlayConf::TrafficAction action=RDAirPlayConf::TrafficFinish;
+  if(state==RDPlayDeck::Stopped) {
+    action=RDAirPlayConf::TrafficStop;
+  }
   QString sql;
   RDSqlQuery *q;
   QDateTime datetime=QDateTime(QDate::currentDate(),QTime::currentTime());
@@ -650,10 +705,8 @@ void RDCartSlot::LogPlayout(RDAirPlayConf::TrafficAction action)
     "ISCI=\""+RDEscapeString(slot_logline->isci())+"\"";
   q=new RDSqlQuery(sql);
   delete q;
-
 }
 
-
 void RDCartSlot::ClearTempCart()
 {
   RDCart *cart=NULL;
@@ -661,7 +714,7 @@ void RDCartSlot::ClearTempCart()
   if(slot_temp_cart) {
     cart=new RDCart(slot_logline->cartNumber());
     if(cart->exists()) {
-      cart->remove(slot_station,slot_user);
+      cart->remove(slot_station,slot_user,slot_config);
     }
     slot_temp_cart=false;
     delete cart;
