@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpodcast.cpp,v 1.6.2.1.2.1 2010/05/11 14:43:12 cvs Exp $
+//      $Id: rdpodcast.cpp,v 1.11 2010/11/24 16:57:38 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,12 +20,34 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <curl/curl.h>
+
 #include <rddb.h>
 #include <rdpodcast.h>
 #include <rdconf.h>
 #include <rdescape_string.h>
 #include <rdurl.h>
 
+//
+// CURL Callbacks
+//
+int PodcastErrorCallback(CURL *curl,curl_infotype type,char *msg,size_t size,
+			void *clientp)
+{
+  char str[1000];
+
+  if(type!=CURLINFO_TEXT) {
+    return 0;
+  }
+  if(size>999) {
+    size=999;
+  }
+  memset(&str,0,size+1);
+  memcpy(str,msg,size);
+  syslog(LOG_DEBUG,"CURL MSG: %s",str);
+  return 0;
+}
+
 
 RDPodcast::RDPodcast(unsigned id)
 {
@@ -271,170 +293,67 @@ void RDPodcast::setStatus(RDPodcast::Status status)
 }
 
 
-QString RDPodcast::audioUploadCommand(const QString &srcfile) const
+bool RDPodcast::removeAudio(RDFeed *feed,QString *err_text,bool log_debug) const
 {
-  QString sql;
-  RDSqlQuery *q;
-  QString cmd;
+  CURL *curl=NULL;
+  struct curl_slist *cmds=NULL;
+  CURLcode err;
+  QUrl *url;
+  bool ret=true;
+  QString currentdir;
+  char urlstr[1024];
+  char userpwd[256];
 
-  //
-  // Get Cast Values
-  //
-  sql=QString().sprintf("select FEED_ID,AUDIO_FILENAME from PODCASTS \
-                         where ID=%u",podcast_id);
-  q=new RDSqlQuery(sql);
-  if(!q->first()) {
-    delete q;
-    return QString();
+  if((curl=curl_easy_init())==NULL) {
+    syslog(LOG_ERR,"unable to initialize curl library\n");
+    return false;
   }
-  unsigned feed_id=q->value(0).toUInt();
-  QString audio_filename=q->value(1).toString();
-  delete q;
-
-  //
-  // Get Feed Values
-  //
-  sql=QString().sprintf("select PURGE_URL,PURGE_USERNAME,PURGE_PASSWORD \
-                         from FEEDS where ID=%u",feed_id);
-  q=new RDSqlQuery(sql);
-  if(!q->first()) {
-    delete q;
-    return QString();
+  url=new QUrl(feed->purgeUrl());
+  strncpy(urlstr,(const char *)(url->protocol()+"://"+url->host()+"/"),1024);
+  curl_easy_setopt(curl,CURLOPT_URL,urlstr);
+  strncpy(userpwd,(const char *)QString().
+		   sprintf("%s:%s",(const char *)feed->purgeUsername(),
+			   (const char *)feed->purgePassword()),256);
+  curl_easy_setopt(curl,CURLOPT_USERPWD,userpwd);
+  curl_easy_setopt(curl,CURLOPT_HTTPAUTH,CURLAUTH_ANY);
+  if(log_debug) {
+    curl_easy_setopt(curl,CURLOPT_VERBOSE,1);
+    curl_easy_setopt(curl,CURLOPT_DEBUGFUNCTION,PodcastErrorCallback);
   }
-  QString purge_url=q->value(0).toString();
-  QString purge_username=q->value(1).toString();
-  QString purge_password=q->value(2).toString();
-  delete q;
-
-  //
-  // Build Command
-  //
-  RDUrl url(purge_url+"/"+audio_filename);
-
-  if(url.protocol()=="file") {
-    cmd=QString().sprintf("cp %s %s",(const char *)srcfile,
-			  (const char *)url.path());
+  currentdir="";
+  if(!url->dirPath().right(url->dirPath().length()-1).isEmpty()) {
+    currentdir=url->dirPath().right(url->dirPath().length()-1)+"/";
   }
-
-  if(url.protocol()=="ftp") {
-    QString dir=RDGetPathPart(url.path());
-    if(dir.right(dir.length()-1).isEmpty()) {
-      cmd=QString().
-	sprintf("lftp -e \"set net:max-retries 1;put %s -o %s;bye\"",
-		(const char *)srcfile,
-		(const char *)RDGetBasePart(url.path()));
-    }
-    else {
-      cmd=QString().
-	sprintf("lftp -e \"set net:max-retries 1;put -O %s %s -o %s;bye\"",
-		(const char *)dir.right(dir.length()-1),
-		(const char *)srcfile,
-		(const char *)RDGetBasePart(url.path()));
-    }
-    if(!purge_username.isEmpty()) {
-      cmd+=QString().sprintf(" -u \"%s:",(const char *)purge_username);
-      if(purge_password.isEmpty()) {
-	cmd+="\"";
-      }
-      else {
-	cmd+=QString().sprintf("%s\"",(const char *)purge_password);
-      }
-    }
-    cmd+=QString().sprintf(" %s",(const char *)url.host());
+  if(!url->fileName().isEmpty()) {
+    currentdir+=url->fileName()+"/";
   }
-
-  if(url.protocol()=="smb") {
-    QString path=RDGetPathPart(url.path());
-    cmd=QString().sprintf("smbclient \"%s\" ",(const char *)url.smbShare());
-      if(!purge_password.isEmpty()) {
-	cmd+=QString().sprintf("\"%s\" ",(const char *)purge_password);
-      }
-      if(!purge_username.isEmpty()) {
-	cmd+=QString().sprintf("-U %s ",(const char *)purge_username);
-      }
-      cmd+=QString().sprintf("-c \"put %s %s\"",(const char *)srcfile,
-			     (const char *)url.smbPath());
+  if(!currentdir.isEmpty()) {
+    cmds=curl_slist_append(cmds,QString().sprintf("cwd %s",
+						  (const char *)currentdir));
   }
+  cmds=curl_slist_append(cmds, QString().sprintf("dele %s",
+	    (const char *)audioFilename()));
+  curl_easy_setopt(curl,CURLOPT_QUOTE,cmds);
+  switch((err=curl_easy_perform(curl))) {
+  case CURLE_OK:
+#ifdef CURLE_QUOTE_ERROR
+  case CURLE_QUOTE_ERROR:  // In case the file is already gone
+#endif  // CURLE_QUOTE_ERROR
+    ret=true;
+    break;
 
-  return cmd;
-}
-
-
-QString RDPodcast::audioPurgeCommand() const
-{
-  QString sql;
-  RDSqlQuery *q;
-  QString cmd;
-
-  //
-  // Get Cast Values
-  //
-  sql=QString().sprintf("select FEED_ID,AUDIO_FILENAME from PODCASTS \
-                         where ID=%u",podcast_id);
-  q=new RDSqlQuery(sql);
-  if(!q->first()) {
-    delete q;
-    return QString();
+  default:
+    ret=false;
+    break;
   }
-  unsigned feed_id=q->value(0).toUInt();
-  QString audio_filename=q->value(1).toString();
-  delete q;
-
-  //
-  // Get Feed Values
-  //
-  sql=QString().sprintf("select PURGE_URL,PURGE_USERNAME,PURGE_PASSWORD \
-                         from FEEDS where ID=%u",feed_id);
-  q=new RDSqlQuery(sql);
-  if(!q->first()) {
-    delete q;
-    return QString();
+  if(err_text!=NULL) {
+    *err_text=curl_easy_strerror(err);
   }
-  QString purge_url=q->value(0).toString();
-  QString purge_username=q->value(1).toString();
-  QString purge_password=q->value(2).toString();
-  delete q;
-
-  RDUrl url(purge_url);
-
-  if(url.protocol()=="file") {
-    cmd=QString().sprintf("rm \"%s/%s\"",(const char *)url.path(),
-			  (const char *)audio_filename);
-  }
-  if(url.protocol()=="ftp") {
-    cmd=QString().sprintf("lftp -e \"set net:max-retries 1;rm %s;bye\"",
-			  (const char *)audio_filename);
-    if(!purge_username.isEmpty()) {
-      cmd+=QString().sprintf(" -u \"%s:",(const char *)purge_username);
-      if(purge_password.isEmpty()) {
-	cmd+="\"";
-      }
-      else {
-	cmd+=QString().sprintf("%s\"",(const char *)purge_password);
-      }
-    }
-    cmd+=QString().sprintf(" ftp://%s%s",(const char *)url.host(),
-				 (const char *)url.path());
-    cmd+=" > /dev/null 2> /dev/null";
-  }
-  if(url.protocol()=="smb") {
-    if(!url.validSmbShare()) {
-      return QString();
-    }
-    QString path=RDGetPathPart(url.path());
-    cmd=QString().sprintf("smbclient \"%s\" ",(const char *)url.smbShare());
-    if(!purge_password.isEmpty()) {
-      cmd+=QString().sprintf("\"%s\" ",(const char *)purge_password);
-    }
-    if(!purge_username.isEmpty()) {
-      cmd+=QString().sprintf("-U %s ",(const char *)purge_username);
-    }
-    cmd+=QString().
-      sprintf("-c \"cd %s;del %s\"",(const char *)url.smbPath(),
-	      (const char *)audio_filename);
-  }  
-
-  return cmd;
+  curl_slist_free_all(cmds);
+  curl_easy_cleanup(curl);
+  delete url;
+    
+  return ret;
 }
 
 
