@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdwavefile.h,v 1.5 2008/10/16 19:28:39 fredg Exp $
+//    $Id: rdwavefile.h,v 1.10.6.1 2013/12/05 17:37:48 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -42,6 +42,7 @@
 
 #include <rdwavedata.h>
 #include <rdringbuffer.h>
+#include <rdsettings.h>
 
 using namespace std;
 
@@ -77,6 +78,7 @@ using namespace std;
 #define LEVL_CHUNK_SIZE 128
 #define SCOT_CHUNK_SIZE 424
 #define AV10_CHUNK_SIZE 512
+#define AIR1_CHUNK_SIZE 2048
 
 //
 // Maximum Header Size for ATX Files
@@ -253,6 +255,9 @@ class RDWaveFile
    **/
    int seekWave(int offset,int whence);
 
+   void getSettings(RDSettings *settings);
+   void setSettings(const RDSettings *settings);
+
   /**
    * Returns true if energy data is available.
    **/
@@ -303,6 +308,7 @@ class RDWaveFile
    * Returns the FormatTag of the WAV file, as defined in the 'FMT' chunk.
    * Values currently understood by RDWaveFile are:
    * WAVE_FORMAT_PCM  Linear PCM Data
+   * WAVE_FORMAT_IEEE_FLOAT IEEE Floating Point Data
    * WAVE_FORMAT_MPEG MPEG-1 Encoded Data
    **/
    unsigned short getFormatTag() const;
@@ -1024,6 +1030,10 @@ class RDWaveFile
    **/
    bool getScotChunk() const;
 
+   bool getAIR1Chunk() const;
+
+   double getNormalizeLevel() const;
+   void setNormalizeLevel(double level);
 
   private:
    RDWaveFile::Type GetType(int fd);
@@ -1045,6 +1055,7 @@ class RDWaveFile
    bool GetList(int);
    bool GetScot(int);
    bool GetAv10(int);
+   bool GetAir1(int);
    bool ReadListElement(unsigned char *buffer,unsigned *offset,unsigned size);
    bool ReadTmcMetadata(int);
    void ReadTmcTag(const QString tag,const QString value);
@@ -1065,6 +1076,8 @@ class RDWaveFile
    unsigned short ReadSword(unsigned char *,unsigned);
    void GetEnergy();
    unsigned LoadEnergy();
+   bool ReadNormalizeLevel(QString wave_file_name);
+   bool ReadEnergyFile(QString wave_file_name);
    void GrowAlloc(size_t size);
    void ValidateMetadata();
 #ifdef HAVE_VORBIS
@@ -1201,6 +1214,11 @@ class RDWaveFile
    QDate scot_end_date;
    QTime scot_end_time;
 
+   bool AIR1_chunk;
+   unsigned char AIR1_chunk_data[AIR1_CHUNK_SIZE];
+
+   double normalize_level; 
+   
    bool av10_chunk;
    unsigned char av10_chunk_data[AV10_CHUNK_SIZE];
    
@@ -1239,6 +1257,7 @@ class RDWaveFile
  * WAVE Format Categories 
  */
 #define WAVE_FORMAT_PCM 0x0001
+#define WAVE_FORMAT_IEEE_FLOAT 0x0003
 #define WAVE_FORMAT_MPEG 0x0050
 
 /*
