@@ -51,19 +51,19 @@
     </message>
     <message>
         <source>&amp;Audition</source>
-        <translation>&amp;Lytt</translation>
+        <translation type="obsolete">&amp;Lytt</translation>
     </message>
     <message>
         <source>&amp;Pause</source>
-        <translation>&amp;Pause</translation>
+        <translation type="obsolete">&amp;Pause</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
-        <translation>&amp;Stopp</translation>
+        <translation type="obsolete">&amp;Stopp</translation>
     </message>
     <message>
         <source>Start</source>
-        <translation>Start</translation>
+        <translation type="obsolete">Start</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -75,24 +75,20 @@
     </message>
     <message>
         <source>Edit Marker</source>
-        <translation>Rediger markør</translation>
+        <translation type="unfinished">Rediger markør</translation>
     </message>
     <message>
         <source>Edit Track</source>
-        <translation>Rediger spor</translation>
+        <translation type="unfinished">Rediger spor</translation>
     </message>
     <message>
         <source>Edit Log Track</source>
-        <translation>Rediger loggspor</translation>
+        <translation type="unfinished">Rediger loggspor</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
         <translation>Overtoning viss førre korga endar før</translation>
     </message>
-    <message>
-        <source>End</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Duplicate Start Time</source>
         <translation type="unfinished"></translation>
@@ -102,6 +98,105 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>HourSelector</name>
+    <message>
+        <source>12a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>8a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>9a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>10a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>11a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>12p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>8p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>9p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>10p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>11p</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ListLog</name>
     <message>
@@ -415,7 +510,7 @@ Tail</source>
     </message>
     <message>
         <source>RDAirPlay - Host:</source>
-        <translation>RDAirPlay-vert:</translation>
+        <translation type="obsolete">RDAirPlay-vert:</translation>
     </message>
     <message>
         <source>Database Error</source>
@@ -495,6 +590,14 @@ LASTAR PÅ NYTT</translation>
         <source>Service:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Host:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
