@@ -51,23 +51,23 @@
     </message>
     <message>
         <source>&amp;Audition</source>
-        <translation>&amp;Audição</translation>
+        <translation type="obsolete">&amp;Audição</translation>
     </message>
     <message>
         <source>&amp;Pause</source>
-        <translation>&amp;Pause</translation>
+        <translation type="obsolete">&amp;Pause</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
-        <translation>&amp;Pare</translation>
+        <translation type="obsolete">&amp;Pare</translation>
     </message>
     <message>
         <source>Start</source>
-        <translation>Início</translation>
+        <translation type="obsolete">Início</translation>
     </message>
     <message>
         <source>End</source>
-        <translation>Fim</translation>
+        <translation type="obsolete">Fim</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -79,15 +79,15 @@
     </message>
     <message>
         <source>Edit Marker</source>
-        <translation>Editar Marcador</translation>
+        <translation type="unfinished">Editar Marcador</translation>
     </message>
     <message>
         <source>Edit Track</source>
-        <translation>Editar Pista</translation>
+        <translation type="unfinished">Editar Pista</translation>
     </message>
     <message>
         <source>Edit Log Track</source>
-        <translation>Editar Pista da Lista</translation>
+        <translation type="unfinished">Editar Pista da Lista</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
@@ -102,6 +102,105 @@
         <translation>Um evento já está agendado com esta hora de início!</translation>
     </message>
 </context>
+<context>
+    <name>HourSelector</name>
+    <message>
+        <source>12a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>8a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>9a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>10a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>11a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>12p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>8p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>9p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>10p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>11p</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ListLog</name>
     <message>
@@ -402,7 +501,7 @@ Log</source>
     </message>
     <message>
         <source>RDAirPlay - Host:</source>
-        <translation>RDAovivo - Cliente:</translation>
+        <translation type="obsolete">RDAovivo - Cliente:</translation>
     </message>
     <message>
         <source>Database Error</source>
@@ -487,6 +586,14 @@ LISTA</translation>
         <source>Service:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Host:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
