@@ -119,7 +119,7 @@ markørar</translation>
     <message>
         <source>This cut is used in one or more RDCatch events!
 Do you still want to delete it?</source>
-        <translation>Dette kuttet er brukt i ei eller fleire RDCatch-hendingar.
+        <translation type="obsolete">Dette kuttet er brukt i ei eller fleire RDCatch-hendingar.
 Er du sikker på at du vil sletta det?</translation>
     </message>
     <message>
@@ -171,11 +171,48 @@ Vil du halda fram?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unable to delete audio!</source>
+        <source>No audio is present in the cut!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No audio is present in the cut!</source>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more cuts are used in one or more RDCatch events!
+Do you still want to delete?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete audio for cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No data copied - you must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -330,6 +367,14 @@ Rip</source>
         <source>Rip Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[none]</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -712,6 +757,30 @@ Notes</source>
         <source>The cart title must be unique!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cond&amp;uctor:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Song &amp;ID:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Beats per Minute:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -811,10 +880,6 @@ Notes</source>
         <source>Cut Report</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cart Data Dump</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Type:</source>
         <translation type="unfinished">Type:</translation>
@@ -831,6 +896,18 @@ Notes</source>
         <source>ALL</source>
         <translation type="unfinished">ALT</translation>
     </message>
+    <message>
+        <source>Cart Data Dump (fixed width)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Data Dump (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prepend Field Names</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -975,7 +1052,7 @@ korg</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
-        <translation>SPELEREKKJEFYLGJE</translation>
+        <translation type="obsolete">SPELEREKKJEFYLGJE</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
@@ -1057,11 +1134,11 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>Sequence</source>
-        <translation>Rekkjefylgje</translation>
+        <translation type="obsolete">Rekkjefylgje</translation>
     </message>
     <message>
         <source>Random</source>
-        <translation>Tilfeldig</translation>
+        <translation type="obsolete">Tilfeldig</translation>
     </message>
     <message>
         <source>TFN</source>
@@ -1069,11 +1146,11 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>RDLibrary - Host:</source>
-        <translation>RDLibrary -- Vert:</translation>
+        <translation type="obsolete">RDLibrary -- Vert:</translation>
     </message>
     <message>
         <source>, User:</source>
-        <translation>, brukar:</translation>
+        <translation type="obsolete">, brukar:</translation>
     </message>
     <message>
         <source>Show Note Bubbles</source>
@@ -1095,6 +1172,30 @@ Vil du sletta ho likevel?</translation>
         <source> Matches</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PUBLISHER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow Cart Dragging</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecordCut</name>
