@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_log.cpp,v 1.87.2.2 2009/11/17 17:45:54 cvs Exp $
+//      $Id: edit_log.cpp,v 1.91.6.4 2013/12/27 22:12:28 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -311,7 +311,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   //
   // Log Event List
   //
-  edit_log_list=new RDListView(this,"edit_log_list");
+  edit_log_list=new DropListView(this,"edit_log_list");
   edit_log_list->setAllColumnsShowFocus(true);
   edit_log_list->setSelectionMode(QListView::Extended);
   edit_log_list->setItemMargin(5);
@@ -344,12 +344,16 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   edit_log_list->setColumnAlignment(12,Qt::AlignHCenter);
   edit_log_list->addColumn(tr("COUNT"));
   edit_log_list->setColumnAlignment(13,Qt::AlignHCenter);
-  connect(edit_log_list,SIGNAL(doubleClicked(QListViewItem *)),
-	  this,SLOT(doubleClickData(QListViewItem *)));
+  if(editing_allowed) {
+    connect(edit_log_list,SIGNAL(doubleClicked(QListViewItem *)),
+	    this,SLOT(doubleClickData(QListViewItem *)));
+    connect(edit_log_list,SIGNAL(cartDropped(int,RDLogLine *)),
+	    this,SLOT(cartDroppedData(int,RDLogLine *)));
+  }
   connect(edit_log_list,SIGNAL(clicked(QListViewItem *)),
-	  this,SLOT(clickedData(QListViewItem *)));
+  	  this,SLOT(clickedData(QListViewItem *)));
   connect(edit_log_list,SIGNAL(selectionChanged()),
-	  this,SLOT(selectionChangedData()));
+  	  this,SLOT(selectionChangedData()));
 
   //
   //  Insert Cart Button
@@ -695,7 +699,8 @@ void EditLog::insertCartButtonData()
   EditLogLine *edit=new EditLogLine(edit_log_event->logLine(line),
 				    &edit_filter,&edit_group,
 				    edit_service_box->currentText(),
-				    &edit_group_list,this,"edit_logline");
+				    &edit_group_list,edit_log_event,line,
+				    this,"edit_logline");
   int ret=edit->exec();
   if(ret>=0) {
     edit_log_event->refresh(line);
@@ -839,7 +844,8 @@ void EditLog::editButtonData()
 	edit_cart=new EditLogLine(edit_log_event->logLine(line),&
 				  edit_filter,&edit_group,
 				  edit_service_box->currentText(),
-				  &edit_group_list,this,"edit_logline");
+				  &edit_group_list,edit_log_event,line,
+				  this,"edit_logline");
 	if(edit_cart->exec()>=0) {
 	  edit_log_event->refresh(item->text(13).toInt());
 	  edit_changed=true;
@@ -1021,6 +1027,25 @@ void EditLog::pasteButtonData()
 }
 
 
+void EditLog::cartDroppedData(int line,RDLogLine *ll)
+{
+  int id;
+
+  edit_log_event->insert(line,1);
+  edit_log_event->setLogLine(line,ll);
+  edit_log_event->logLine(line)->setTransType(edit_default_trans);
+  edit_log_event->logLine(line)->setFadeupGain(-3000);
+  edit_log_event->logLine(line)->setFadedownGain(-3000);
+  edit_log_event->refresh(line);
+  edit_changed=true;
+  RefreshList();
+  /*
+  SelectRecord(id);
+  UpdateSelection();
+  */
+}
+
+
 void EditLog::saveData()
 {
   if(!ValidateSvc()) {
@@ -1029,9 +1054,13 @@ void EditLog::saveData()
       return;
     }
   }
+  if(!DeleteTracks()) {
+    QMessageBox::warning(this,tr("RDLogEdit"),
+			 tr("Unable to save log, audio deletion error!"));
+    return;
+  }
   edit_log_event->save();
   edit_changed=false;
-  DeleteTracks();
   edit_log->setAutoRefresh(edit_autorefresh_box->currentItem()==0);
   edit_log->
     setModifiedDatetime(QDateTime(QDate::currentDate(),QTime::currentTime()));
@@ -1297,7 +1326,7 @@ void EditLog::RefreshLine(RDListViewItem *item)
       case RDLogLine::Hard:
 	item->setText(1,QString("T")+edit_log_event->
 		   logLine(line)->startTime(RDLogLine::Logged).
-		   toString("hh:mm:ss"));
+		      toString("hh:mm:ss.zzz").left(10));
 	break;
 
       default:
@@ -1305,12 +1334,12 @@ void EditLog::RefreshLine(RDListViewItem *item)
 	   startTime(RDLogLine::Logged).isNull()) {
 	  item->setText(1,edit_log_event->
 			blockStartTime(line).
-			toString("hh:mm:ss"));
+			toString("hh:mm:ss.zzz").left(10));
 	}
 	else {
 	  item->setText(1,edit_log_event->
 			logLine(line)->startTime(RDLogLine::Logged).
-			toString("hh:mm:ss"));
+			toString("hh:mm:ss.zzz").left(10));
 	}
 	break;
   }
@@ -1670,12 +1699,16 @@ void EditLog::UpdateTracks()
 }
 
 
-void EditLog::DeleteTracks()
+bool EditLog::DeleteTracks()
 {
   RDCart *cart;
   for(unsigned i=0;i<edit_deleted_tracks.size();i++) {
     cart=new RDCart(edit_deleted_tracks[i]);
-    cart->remove();
+    if(!cart->remove(rdstation_conf,rduser,log_config)) {
+      delete cart;
+      return false;
+    }
     delete cart;
   }
+  return true;
 }
