@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_log.h,v 1.33 2008-10-08 18:43:30 fredg Exp $
+//      $Id: edit_log.h,v 1.36.8.1 2013/12/27 22:12:29 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,10 +41,9 @@
 #include <rdgroup_list.h>
 #include <rdsimpleplayer.h>
 
+#include <drop_listview.h>
 #include <list_reports.h>
 
-using namespace std;
-
 //
 // Widget Settings
 //
@@ -62,6 +61,7 @@ class EditLog : public QDialog
   
  private slots:
   void descriptionChangedData(const QString &);
+  void selectPurgeDateData();
   void serviceActivatedData(const QString &svcname);
   void dateValueChangedData(const QDate &);
   void startDateEnabledData(bool);
@@ -78,6 +78,7 @@ class EditLog : public QDialog
   void cutButtonData();
   void copyButtonData();
   void pasteButtonData();
+  void cartDroppedData(int line,RDLogLine *ll);
   void saveData();
   void saveasData();
   void reportsData();
@@ -98,7 +99,7 @@ class EditLog : public QDialog
   bool UpdateColor(RDListViewItem *item,RDLogLine *logline);
   void SelectRecord(int id);
   void UpdateTracks();
-  void DeleteTracks();
+  bool DeleteTracks();
   bool ValidateSvc();
   RDListViewItem *SingleSelection();
   RDLog *edit_log;
@@ -123,7 +124,7 @@ class EditLog : public QDialog
   QCheckBox *edit_startdate_box;
   QLabel *edit_enddate_label;
   QCheckBox *edit_enddate_box;
-  RDListView *edit_log_list;
+  DropListView *edit_log_list;
   QString edit_filter;
   QString edit_group;
   QPixmap *edit_playout_map;
@@ -170,6 +171,10 @@ class EditLog : public QDialog
   QLineEdit *edit_stoptime_edit;
   QLabel *edit_endtime_label;
   QLineEdit *edit_endtime_edit;
+  QCheckBox *edit_purgedate_box;
+  QLabel *edit_purgedate_label;
+  QDateEdit *edit_purgedate_edit;
+  QPushButton *edit_purgedate_button;
 };
 
 
